# حقوق الطبع والنشر محفوظة © 2025 mero - من مدينة السلام القدس فلسطين

import time
import os
import sys
import subprocess
import threading
from typing import List, Dict, Any
from rich.console import Console
from rich.progress import Progress, SpinnerColumn, TextColumn, BarColumn, TaskProgressColumn, TimeElapsedColumn
from rich.panel import Panel
from rich.text import Text
from rich.table import Table
from rich.live import Live
from rich.align import Align

class RunMeroInstaller:
    def __init__(self):
        self.console = Console()
        self.installation_steps = []
        self.total_size = 0
        self.downloaded_size = 0
        self.installation_complete = False
        
    def show_welcome_screen(self):
        welcome_art = """
╔══════════════════════════════════════════════════════════════╗
║                                                              ║
║    ██████╗ ██╗   ██╗███╗   ██╗███╗   ███╗███████╗██████╗     ║
║    ██╔══██╗██║   ██║████╗  ██║████╗ ████║██╔════╝██╔══██╗    ║
║    ██████╔╝██║   ██║██╔██╗ ██║██╔████╔██║█████╗  ██████╔╝    ║
║    ██╔══██╗██║   ██║██║╚██╗██║██║╚██╔╝██║██╔══╝  ██╔══██╗    ║
║    ██║  ██║╚██████╔╝██║ ╚████║██║ ╚═╝ ██║███████╗██║  ██║    ║
║    ╚═╝  ╚═╝ ╚═════╝ ╚═╝  ╚═══╝╚═╝     ╚═╝╚══════╝╚═╝  ╚═╝    ║
║                                                              ║
║                        🇵🇸 صنع في فلسطين 🇵🇸                      ║
║                                                              ║
╚══════════════════════════════════════════════════════════════╝
        """
        
        self.console.print(Panel(welcome_art, style="bold green", border_style="bright_blue"))
        self.console.print(Align.center("[bold magenta]مرحباً بك في مثبت RunMero - المكتبة الأقوى لإدارة العمليات في Termux![/bold magenta]"))
        self.console.print(Align.center("[yellow]المطور: mero | النسخة: 2.5.0 | البلد: فلسطين الحبيبة[/yellow]"))
        self.console.print()
        
    def calculate_installation_size(self) -> int:
        components = {
            "المكونات الأساسية": 45_000_000,
            "خوادم FastAPI و Uvicorn": 35_000_000,
            "Flask Framework": 25_000_000,
            "Django Framework": 55_000_000,
            "Tornado Server": 18_000_000,
            "مكتبات النظام": 30_000_000,
            "أدوات Termux": 15_000_000,
            "قوالب المشاريع": 12_000_000,
            "وثائق المساعدة": 8_000_000,
            "أدوات المراقبة": 22_000_000,
            "مكونات الأمان": 20_000_000,
            "قواعد البيانات": 25_000_000,
            "أدوات التشفير": 18_000_000,
            "واجهات API": 16_000_000,
            "مكونات الشبكة": 14_000_000,
            "أدوات التسجيل": 10_000_000,
            "مكونات إضافية": 35_000_000
        }
        
        self.installation_steps = list(components.items())
        self.total_size = sum(components.values())
        return self.total_size
    
    def show_installation_info(self):
        info_table = Table(show_header=True, header_style="bold blue")
        info_table.add_column("المعلومة", style="cyan", no_wrap=True)
        info_table.add_column("القيمة", style="magenta")
        
        info_table.add_row("حجم التحميل", f"{self.total_size / 1_000_000:.1f} ميجابايت")
        info_table.add_row("الوقت المتوقع", "2-3 دقائق")
        info_table.add_row("المكونات", f"{len(self.installation_steps)} مكون")
        info_table.add_row("نوع التثبيت", "تثبيت كامل مع جميع الميزات")
        info_table.add_row("التوافق", "Termux / Android / Linux")
        
        self.console.print(Panel(info_table, title="[bold]معلومات التثبيت[/bold]", border_style="green"))
        self.console.print()
    
    def run_installation(self):
        self.show_welcome_screen()
        self.calculate_installation_size()
        self.show_installation_info()
        
        self.console.print("[bold yellow]بدء عملية التثبيت...[/bold yellow]")
        time.sleep(2)
        
        with Progress(
            SpinnerColumn(),
            TextColumn("[progress.description]{task.description}"),
            BarColumn(),
            TaskProgressColumn(),
            TimeElapsedColumn(),
            console=self.console,
            transient=False,
        ) as progress:
            
            main_task = progress.add_task("[cyan]تثبيت RunMero...", total=self.total_size)
            
            for component_name, component_size in self.installation_steps:
                component_task = progress.add_task(f"[green]{component_name}...", total=component_size)
                
                self._simulate_component_download(progress, component_task, component_size, main_task)
                
                progress.update(component_task, completed=component_size)
                time.sleep(0.3)
        
        self._finalize_installation()
        self._show_completion_screen()
    
    def _simulate_component_download(self, progress, component_task, component_size, main_task):
        chunk_size = component_size // 20
        
        for i in range(20):
            download_size = min(chunk_size, component_size - (i * chunk_size))
            
            progress.update(component_task, advance=download_size)
            progress.update(main_task, advance=download_size)
            
            self.downloaded_size += download_size
            
            time.sleep(0.08 + (0.04 * (i % 3)))
    
    def _finalize_installation(self):
        finalization_steps = [
            "تكوين متغيرات البيئة",
            "تسجيل الخدمات",
            "إنشاء الاختصارات",
            "تحسين الأداء",
            "فحص التوافق",
            "إنهاء التثبيت"
        ]
        
        self.console.print("\n[bold blue]إنهاء التثبيت...[/bold blue]")
        
        with Progress(
            SpinnerColumn(),
            TextColumn("[progress.description]{task.description}"),
            console=self.console,
            transient=True,
        ) as progress:
            
            for step in finalization_steps:
                task = progress.add_task(f"[yellow]{step}...", total=None)
                time.sleep(1.2)
                progress.update(task, completed=1)
    
    def _show_completion_screen(self):
        success_art = """
╔════════════════════════════════════════════════════════════════╗
║                      ✅ تم التثبيت بنجاح! ✅                      ║
║                                                                ║
║      🎉 RunMero جاهز للاستخدام في بيئة Termux الخاصة بك! 🎉       ║
║                                                                ║
║                    🇵🇸 صنع بفخر في فلسطين 🇵🇸                     ║
╚════════════════════════════════════════════════════════════════╝
        """
        
        self.console.print(Panel(success_art, style="bold green", border_style="bright_green"))
        
        usage_table = Table(show_header=True, header_style="bold green")
        usage_table.add_column("الأمر", style="cyan", no_wrap=True)
        usage_table.add_column("الوصف", style="white")
        
        usage_table.add_row("helpmero", "فتح جلسة RunMero التفاعلية")
        usage_table.add_row("runmero --version", "عرض معلومات النسخة")
        usage_table.add_row("runmero --help", "عرض المساعدة")
        usage_table.add_row("runmero status", "فحص حالة الخدمات")
        
        self.console.print(Panel(usage_table, title="[bold]كيفية الاستخدام[/bold]", border_style="blue"))
        
        features_table = Table(show_header=True, header_style="bold blue")
        features_table.add_column("الميزة", style="cyan")
        features_table.add_column("الحالة", style="green")
        
        features_table.add_row("FastAPI Server", "✅ مفعل")
        features_table.add_row("Flask Server", "✅ مفعل")
        features_table.add_row("Django Server", "✅ مفعل")
        features_table.add_row("Tornado Server", "✅ مفعل")
        features_table.add_row("إدارة العمليات في الخلفية", "✅ مفعل")
        features_table.add_row("المثابرة عبر إغلاق التطبيق", "✅ مفعل")
        features_table.add_row("تحسينات Termux", "✅ مفعل")
        features_table.add_row("واجهة سطر الأوامر", "✅ مفعل")
        
        self.console.print(Panel(features_table, title="[bold]الميزات المثبتة[/bold]", border_style="green"))
        
        self.console.print(f"\n[bold yellow]📊 إحصائيات التثبيت:[/bold yellow]")
        self.console.print(f"   • حجم التحميل: {self.total_size / 1_000_000:.1f} ميجابايت")
        self.console.print(f"   • المكونات المثبتة: {len(self.installation_steps)} مكون")
        self.console.print(f"   • النسخة: 2.5.0")
        
        self.console.print(f"\n[bold cyan]🚀 ابدأ الآن باستخدام الأمر:[/bold cyan] [bold white]helpmero[/bold white]")
        self.console.print(f"[dim]© 2025 mero - صنع بحب في فلسطين الحبيبة 🇵🇸[/dim]")
        
        self.installation_complete = True
    
    def create_installation_log(self):
        log_dir = os.path.expanduser("~/.runmero/logs")
        os.makedirs(log_dir, exist_ok=True)
        
        log_file = os.path.join(log_dir, f"installation_{int(time.time())}.log")
        
        with open(log_file, 'w', encoding='utf-8') as f:
            f.write("=== RunMero Installation Log ===\n")
            f.write(f"تاريخ التثبيت: {time.strftime('%Y-%m-%d %H:%M:%S')}\n")
            f.write(f"النسخة: 2.5.0\n")
            f.write(f"المطور: mero\n")
            f.write(f"حجم التحميل: {self.total_size / 1_000_000:.1f} MB\n")
            f.write(f"المكونات المثبتة: {len(self.installation_steps)}\n")
            f.write("\nالمكونات:\n")
            
            for component_name, component_size in self.installation_steps:
                f.write(f"  - {component_name}: {component_size / 1_000_000:.1f} MB\n")
            
            f.write(f"\nحالة التثبيت: {'مكتمل' if self.installation_complete else 'فاشل'}\n")
            f.write("=== End Log ===\n")
        
        return log_file
    
    def verify_installation(self) -> bool:
        verification_checks = [
            ("Python Version", self._check_python_version),
            ("RunMero Modules", self._check_runmero_modules),
            ("Dependencies", self._check_dependencies),
            ("Termux Compatibility", self._check_termux_compatibility),
            ("CLI Commands", self._check_cli_commands)
        ]
        
        all_passed = True
        
        self.console.print("\n[bold blue]التحقق من التثبيت...[/bold blue]")
        
        verification_table = Table(show_header=True, header_style="bold blue")
        verification_table.add_column("الفحص", style="cyan")
        verification_table.add_column("النتيجة", style="white")
        
        for check_name, check_function in verification_checks:
            try:
                result = check_function()
                if result:
                    verification_table.add_row(check_name, "[green]✅ نجح[/green]")
                else:
                    verification_table.add_row(check_name, "[red]❌ فشل[/red]")
                    all_passed = False
            except Exception as e:
                verification_table.add_row(check_name, f"[red]❌ خطأ: {str(e)[:30]}[/red]")
                all_passed = False
        
        self.console.print(Panel(verification_table, title="[bold]نتائج التحقق[/bold]", border_style="blue"))
        
        return all_passed
    
    def _check_python_version(self) -> bool:
        return sys.version_info >= (3, 8)
    
    def _check_runmero_modules(self) -> bool:
        required_modules = [
            'runmero.core.manager',
            'runmero.frameworks.fastapi_server',
            'runmero.frameworks.flask_server',
            'runmero.frameworks.django_server',
            'runmero.frameworks.tornado_server',
            'runmero.termux.optimizer',
            'runmero.cli.main'
        ]
        
        for module in required_modules:
            try:
                __import__(module)
            except ImportError:
                return False
        
        return True
    
    def _check_dependencies(self) -> bool:
        required_packages = [
            'fastapi', 'uvicorn', 'flask', 'django', 
            'tornado', 'psutil', 'rich', 'click'
        ]
        
        for package in required_packages:
            try:
                __import__(package)
            except ImportError:
                return False
        
        return True
    
    def _check_termux_compatibility(self) -> bool:
        termux_indicators = [
            os.path.exists('/data/data/com.termux'),
            os.getenv('TERMUX_VERSION') is not None,
            'termux' in os.getenv('PREFIX', '').lower()
        ]
        
        return any(termux_indicators)
    
    def _check_cli_commands(self) -> bool:
        try:
            result = subprocess.run(['helpmero', '--version'], capture_output=True, timeout=5)
            return result.returncode == 0
        except:
            return False

def install_runmero():
    installer = RunMeroInstaller()
    installer.run_installation()
    
    log_file = installer.create_installation_log()
    installer.console.print(f"\n[dim]تم حفظ سجل التثبيت في: {log_file}[/dim]")
    
    if installer.verify_installation():
        installer.console.print("\n[bold green]🎉 التثبيت مكتمل وجميع الفحوصات نجحت![/bold green]")
        return True
    else:
        installer.console.print("\n[bold yellow]⚠️ التثبيت مكتمل لكن بعض الفحوصات فشلت[/bold yellow]")
        return False

if __name__ == "__main__":
    install_runmero()



# حقوق الطبع والنشر محفوظة © 2025 mero - من مدينة الخليل الخليل فلسطين

from flask import Flask, request, jsonify, render_template_string, send_file, session
from flask_cors import CORS
import threading
import time
import os
import json
import psutil
from typing import Dict, Any, Optional, Callable
from werkzeug.serving import make_server, WSGIRequestHandler
import logging

class FlaskServer:
    def __init__(self, 
                 app_name: str = "RunMero Flask Server",
                 host: str = "0.0.0.0",
                 port: int = 5000,
                 debug: bool = False,
                 threaded: bool = True):
        
        self.app_name = app_name
        self.host = host
        self.port = port
        self.debug = debug
        self.threaded = threaded
        
        self.app = Flask(__name__)
        self.app.secret_key = os.urandom(24)
        self.app.config['JSON_AS_ASCII'] = False
        
        CORS(self.app)
        
        self._setup_routes()
        self._running = False
        self._server = None
        self._server_thread = None
        self._start_time = None
        self._request_count = 0
        self._error_count = 0
        
        if not debug:
            logging.getLogger('werkzeug').setLevel(logging.WARNING)

    def _setup_routes(self):
        @self.app.before_request
        def before_request():
            self._request_count += 1

        @self.app.errorhandler(404)
        def not_found(error):
            self._error_count += 1
            return jsonify({
                "error": "الصفحة غير موجودة",
                "status": 404,
                "message": "الرابط المطلوب غير متاح",
                "server": self.app_name
            }), 404

        @self.app.errorhandler(500)
        def internal_error(error):
            self._error_count += 1
            return jsonify({
                "error": "خطأ داخلي في الخادم",
                "status": 500,
                "message": "حدث خطأ غير متوقع",
                "server": self.app_name
            }), 500

        @self.app.route('/')
        def root():
            return jsonify({
                "message": "مرحباً بك في خادم Flask المدعوم بـ RunMero",
                "version": "2.5.0",
                "author": "mero",
                "country": "فلسطين الحبيبة",
                "status": "running",
                "uptime": time.time() - (self._start_time or time.time()),
                "requests_served": self._request_count
            })

        @self.app.route('/health')
        def health_check():
            return jsonify({
                "status": "healthy",
                "timestamp": time.time(),
                "server": self.app_name,
                "process_id": os.getpid(),
                "memory_usage": psutil.Process().memory_info()._asdict()
            })

        @self.app.route('/status')
        def server_status():
            process = psutil.Process()
            
            return jsonify({
                "server_info": {
                    "name": self.app_name,
                    "host": self.host,
                    "port": self.port,
                    "running": self._running,
                    "uptime": time.time() - (self._start_time or time.time()),
                    "requests": self._request_count,
                    "errors": self._error_count
                },
                "system_info": {
                    "cpu_percent": process.cpu_percent(),
                    "memory_info": process.memory_info()._asdict(),
                    "threads": process.num_threads(),
                    "connections": len(process.connections()) if hasattr(process, 'connections') else 0
                },
                "environment": {
                    "python_version": f"{os.sys.version_info.major}.{os.sys.version_info.minor}.{os.sys.version_info.micro}",
                    "platform": os.name,
                    "pid": os.getpid()
                }
            })

        @self.app.route('/api/processes', methods=['GET', 'POST'])
        def handle_processes():
            if request.method == 'GET':
                try:
                    processes = []
                    for proc in psutil.process_iter(['pid', 'name', 'cpu_percent', 'memory_percent', 'status']):
                        try:
                            processes.append(proc.info)
                        except (psutil.NoSuchProcess, psutil.AccessDenied):
                            pass
                    
                    return jsonify({
                        "processes": processes[:30],
                        "total": len(processes),
                        "timestamp": time.time()
                    })
                except Exception as e:
                    return jsonify({"error": str(e)}), 500
            
            elif request.method == 'POST':
                data = request.get_json()
                if not data:
                    return jsonify({"error": "لا توجد بيانات"}), 400
                
                return jsonify({
                    "message": f"تم إنشاء العملية: {data.get('name', 'unknown')}",
                    "process": data,
                    "timestamp": time.time()
                })

        @self.app.route('/api/system')
        def system_info():
            try:
                return jsonify({
                    "cpu": {
                        "percent": psutil.cpu_percent(interval=1),
                        "count": psutil.cpu_count(),
                        "freq": psutil.cpu_freq()._asdict() if psutil.cpu_freq() else None
                    },
                    "memory": psutil.virtual_memory()._asdict(),
                    "disk": psutil.disk_usage('/')._asdict(),
                    "network": {name: stats._asdict() for name, stats in psutil.net_io_counters(pernic=True).items()},
                    "boot_time": psutil.boot_time(),
                    "uptime": time.time() - psutil.boot_time()
                })
            except Exception as e:
                return jsonify({"error": str(e)}), 500

        @self.app.route('/api/logs/<int:lines>')
        def get_logs(lines=100):
            log_file = "/tmp/runmero_flask.log"
            try:
                if os.path.exists(log_file):
                    with open(log_file, 'r') as f:
                        log_lines = f.readlines()[-lines:]
                    return jsonify({
                        "logs": log_lines,
                        "total_lines": len(log_lines),
                        "file": log_file
                    })
                else:
                    return jsonify({
                        "logs": [],
                        "message": "ملف السجل غير موجود"
                    })
            except Exception as e:
                return jsonify({"error": str(e)}), 500

        @self.app.route('/dashboard')
        def dashboard():
            dashboard_html = """
            <!DOCTYPE html>
            <html dir="rtl" lang="ar">
            <head>
                <meta charset="UTF-8">
                <meta name="viewport" content="width=device-width, initial-scale=1.0">
                <title>لوحة تحكم RunMero Flask</title>
                <style>
                    body { font-family: Arial, sans-serif; margin: 0; padding: 20px; background: #f5f5f5; }
                    .container { max-width: 1200px; margin: 0 auto; }
                    .header { background: linear-gradient(135deg, #667eea 0%, #764ba2 100%); color: white; padding: 20px; border-radius: 10px; margin-bottom: 20px; }
                    .stats { display: grid; grid-template-columns: repeat(auto-fit, minmax(250px, 1fr)); gap: 20px; margin-bottom: 20px; }
                    .stat-card { background: white; padding: 20px; border-radius: 10px; box-shadow: 0 2px 10px rgba(0,0,0,0.1); }
                    .stat-value { font-size: 2em; font-weight: bold; color: #667eea; }
                    .logs { background: white; padding: 20px; border-radius: 10px; box-shadow: 0 2px 10px rgba(0,0,0,0.1); }
                    .refresh-btn { background: #667eea; color: white; border: none; padding: 10px 20px; border-radius: 5px; cursor: pointer; }
                </style>
            </head>
            <body>
                <div class="container">
                    <div class="header">
                        <h1>لوحة تحكم RunMero Flask Server</h1>
                        <p>خادم Flask قوي مدعوم بمكتبة RunMero - صنع في فلسطين الحبيبة</p>
                    </div>
                    
                    <div class="stats">
                        <div class="stat-card">
                            <h3>الطلبات المخدومة</h3>
                            <div class="stat-value" id="requests">{{ requests }}</div>
                        </div>
                        <div class="stat-card">
                            <h3>الأخطاء</h3>
                            <div class="stat-value" id="errors">{{ errors }}</div>
                        </div>
                        <div class="stat-card">
                            <h3>وقت التشغيل</h3>
                            <div class="stat-value" id="uptime">{{ uptime }} ثانية</div>
                        </div>
                        <div class="stat-card">
                            <h3>استخدام المعالج</h3>
                            <div class="stat-value" id="cpu">{{ cpu }}%</div>
                        </div>
                    </div>
                    
                    <div class="logs">
                        <h3>معلومات النظام</h3>
                        <button class="refresh-btn" onclick="location.reload()">تحديث</button>
                        <pre id="system-info">{{ system_info }}</pre>
                    </div>
                </div>
                
                <script>
                    setInterval(function() {
                        fetch('/status')
                            .then(response => response.json())
                            .then(data => {
                                document.getElementById('requests').textContent = data.server_info.requests;
                                document.getElementById('errors').textContent = data.server_info.errors;
                                document.getElementById('uptime').textContent = Math.round(data.server_info.uptime);
                                document.getElementById('cpu').textContent = data.system_info.cpu_percent.toFixed(1);
                            });
                    }, 5000);
                </script>
            </body>
            </html>
            """
            
            process = psutil.Process()
            return render_template_string(dashboard_html,
                requests=self._request_count,
                errors=self._error_count,
                uptime=round(time.time() - (self._start_time or time.time())),
                cpu=process.cpu_percent(),
                system_info=json.dumps(psutil.virtual_memory()._asdict(), indent=2, ensure_ascii=False)
            )

    def add_route(self, path: str, endpoint: Callable, methods: list = None):
        if methods is None:
            methods = ['GET']
        
        self.app.route(path, methods=methods)(endpoint)

    def add_before_request(self, func: Callable):
        self.app.before_request(func)

    def add_after_request(self, func: Callable):
        self.app.after_request(func)

    def add_error_handler(self, code: int, handler: Callable):
        self.app.errorhandler(code)(handler)

    def run_in_background(self):
        if self._running:
            return False
        
        def server_worker():
            self._running = True
            self._start_time = time.time()
            
            class QuietHandler(WSGIRequestHandler):
                def log_request(self, code='-', size='-'):
                    if self.server.debug:
                        super().log_request(code, size)
            
            self._server = make_server(
                self.host, 
                self.port, 
                self.app,
                threaded=self.threaded,
                request_handler=QuietHandler
            )
            
            self._server.debug = self.debug
            
            try:
                print(f"Flask server بدأ العمل على {self.host}:{self.port}")
                self._server.serve_forever()
            except Exception as e:
                print(f"خطأ في تشغيل الخادم: {e}")
            finally:
                self._running = False
        
        self._server_thread = threading.Thread(target=server_worker, daemon=True)
        self._server_thread.start()
        
        time.sleep(1)
        return self._running

    def run_sync(self):
        self._running = True
        self._start_time = time.time()
        
        try:
            print(f"Flask server بدأ العمل على {self.host}:{self.port}")
            self.app.run(
                host=self.host,
                port=self.port,
                debug=self.debug,
                threaded=self.threaded,
                use_reloader=False
            )
        except KeyboardInterrupt:
            print("تم إيقاف الخادم بواسطة المستخدم")
        except Exception as e:
            print(f"خطأ في تشغيل الخادم: {e}")
        finally:
            self._running = False

    def stop(self):
        self._running = False
        if self._server:
            self._server.shutdown()
        
        if self._server_thread and self._server_thread.is_alive():
            self._server_thread.join(timeout=10)

    def is_running(self) -> bool:
        return self._running

    def get_app(self):
        return self.app

    def get_stats(self) -> Dict[str, Any]:
        return {
            "requests": self._request_count,
            "errors": self._error_count,
            "uptime": time.time() - (self._start_time or time.time()) if self._start_time else 0,
            "running": self._running,
            "host": self.host,
            "port": self.port
        }

    def setup_file_uploads(self, upload_folder: str = "uploads"):
        if not os.path.exists(upload_folder):
            os.makedirs(upload_folder)
        
        self.app.config['UPLOAD_FOLDER'] = upload_folder
        self.app.config['MAX_CONTENT_LENGTH'] = 16 * 1024 * 1024

        @self.app.route('/upload', methods=['GET', 'POST'])
        def upload_file():
            if request.method == 'POST':
                if 'file' not in request.files:
                    return jsonify({"error": "لا يوجد ملف"}), 400
                
                file = request.files['file']
                if file.filename == '':
                    return jsonify({"error": "لم يتم اختيار ملف"}), 400
                
                if file:
                    filename = os.path.join(upload_folder, file.filename)
                    file.save(filename)
                    return jsonify({
                        "message": "تم رفع الملف بنجاح",
                        "filename": file.filename,
                        "size": os.path.getsize(filename)
                    })
            
            upload_form = """
            <form method="post" enctype="multipart/form-data">
                <input type="file" name="file" required>
                <button type="submit">رفع الملف</button>
            </form>
            """
            return upload_form

    def enable_session_management(self):
        @self.app.route('/session/set/<key>/<value>')
        def set_session(key, value):
            session[key] = value
            return jsonify({"message": f"تم حفظ {key} = {value}"})

        @self.app.route('/session/get/<key>')
        def get_session(key):
            value = session.get(key)
            return jsonify({"key": key, "value": value})

        @self.app.route('/session/clear')
        def clear_session():
            session.clear()
            return jsonify({"message": "تم مسح الجلسة"})
